@@ -9,8 +9,8 @@ from .app import app
 
 load_dotenv()
 
-CURDIR = os.path.split(os.path.realpath(__file__))[0]
-VERSION = "0.1.9"
+CURDIR = os.path.dirname(os.path.realpath(__file__))
+VERSION = "0.2.0"
 
 def create_folders():
     if not os.path.exists(os.path.join(CURDIR, 'projects')):
